"""
$RCSfile: testCVSFile.py,v $
Unit tests for CVSFile product

Author: <a href="mailto:cstrong@arielpartners.com">Craeg Strong</a>
Release: 1.0
"""

import os, sys, tempfile
execfile(os.path.join(sys.path[0], 'framework.py'))

command_separator       = ';'
if sys.platform == 'win32':
    command_separator = '&'

tmpDirectory = "/tmp"
if sys.platform == 'win32':
    tmpDirectory = "c:/tmp" # use forward slash b/c backslash is special char

import Zope
from ZPublisher.HTTPRequest import HTTPRequest
from ZPublisher.HTTPResponse import HTTPResponse

from Products.CVSFile.CVSFile import runCommand
from Products.CVSFile.CVSFile import CVSFile
from Products.CVSFile.SandboxInfo import SandboxInfo
from Products.CVSFile.CVSSandboxRegistry import CVSSandboxRegistry
from Products.CVSFile.CVSSandboxRegistry import canonicalizeDir

class TestCVSFile(unittest.TestCase):

    def setUp(self):
        env = { 'SERVER_NAME': 'test',
                'SERVER_PORT': '80' }
        self._request = HTTPRequest(sys.stdin, env, HTTPResponse())

        self._testModule = 'cvsTest'
        self._testFile   = 'testfile.txt'

        cvsroot = os.environ.get('CVSROOT', None)
        if not cvsroot:
            raise EnvironmentError, "You must have CVSROOT defined to run these tests"

        basedir = os.path.join(tmpDirectory, 'testSandbox')

        self._si = SandboxInfo("test1", canonicalizeDir(basedir), cvsroot)

        self._reg = CVSSandboxRegistry("qa", "QA Sandboxes",
                                       "These are the sandboxes for testing",
                                       self._si)
    def createTestModule(self):
        print """
        Make sure to have your CVS administrator remove the
        %s module from the CVS repository after running these
        tests
        """ % self._testModule
        dirname  = os.path.join(tmpDirectory, self._testModule)
        filename = os.path.join(dirname, self._testFile)
        os.mkdir(dirname)
        touchfile = open(filename, 'wb') # create zero-length file
        touchfile.write("this is a test file")
        touchfile.close()
        command = "cd %s %s cvs import -m testing %s ArielPartners start" % (dirname,
                                                                             command_separator,
                                                                             self._testModule)
        output = runCommand(command)
        print output
        os.remove(filename)
        os.rmdir(dirname)

    def createTestSandbox(self):
        try:
            os.mkdir(self._si.basedir)
        except:
            pass
        output = self._reg.checkoutSandbox(self._testModule, '', self._si)
        print output

    def testUpdateNoChange(self):
        self.createTestModule()
        self.createTestSandbox()
        
        self._ef = CVSFile('ascii', 'Ascii File',
                           'I am ASCII',
                           os.path.join(self._testModule, self._testFile))
        output = self._ef.updateFile(self._si)
        print output

# TBD: make this more robust, add more tests
# Right now, this is not idempotent :-(
framework()
